@@ -60,6 +60,10 @@ CFparse <- function(cf, x) {
   out <- .parse_timestamp(cf@datum, x)
   if (anyNA(out$year))
     warning("Some dates could not be parsed. Result contains `NA` values.")
+  if (length(unique(out$tz)) > 1)
+    warning("Timestamps have multiple time zones. Some or all may be different from the datum time zone.")
+  else if (out$tz[1] != CFtimezone(cf))
+    warning("Timestamps have time zone that is different from the datum.")
   return(out)
 }
 
@@ -186,7 +190,7 @@ CFparse <- function(cf, x) {
   cap$day[is.na(cap$day)] <- 1
 
   # Check date validity
-  invalid <- mapply(function(y, m, d) {!.is_valid_calendar_date(y, m, d, datum@cal_id)},
+  invalid <- mapply(function(y, m, d) {!.is_valid_calendar_date(y, m, d, calendar_id(datum))},
                     cap$year, cap$month, cap$day)
   if (nrow(datum@origin) > 0) {
     earlier <- mapply(function(y, m, d, dy, dm, dd) {
@@ -206,7 +210,7 @@ CFparse <- function(cf, x) {
   if (nrow(datum@origin) == 0) {        # if there's no datum yet, don't calculate offsets
     cap$offset <- rep(0, nrow(cap))     # this happens, f.i., when a CFdatum is created
   } else {
-    days <- switch(datum@cal_id,
+    days <- switch(calendar_id(datum),
                    .date2offset_standard(cap, datum@origin),
                    .date2offset_julian(cap, datum@origin),
                    .date2offset_360day(cap, datum@origin),
